@@ -207,38 +207,38 @@
 #
 # Validate 'sspoints' object generated by .pl_main_basic()
 #
-.validate.sspoints <- function(sspoints) {
-  .validate_points_common(sspoints, "sspoints")
+.validate.sspoints <- function(x) {
+  .validate_points_common(x, "sspoints")
 }
 
 #
 # Validate 'mspoints' object generated by .pl_main_basic()
 #
-.validate.mspoints <- function(mspoints) {
-  .validate_points_common(mspoints, "mspoints")
+.validate.mspoints <- function(x) {
+  .validate_points_common(x, "mspoints")
 }
 
 #
 # Validate 'smpoints' object generated by .pl_main_basic()
 #
-.validate.smpoints <- function(smpoints) {
-  .validate_points_common(smpoints, "smpoints")
+.validate.smpoints <- function(x) {
+  .validate_points_common(x, "smpoints")
 }
 
 #
 # Validate 'mmpoints' object generated by .pl_main_basic()
 #
-.validate.mmpoints <- function(mmpoints) {
-  .validate_points_common(mmpoints, "mmpoints")
+.validate.mmpoints <- function(x) {
+  .validate_points_common(x, "mmpoints")
 }
 
 #
 # Validate 'pointgrp' object generated by .summarize_points()
 #
-.validate.pointgrp <- function(pointgrp) {
+.validate.pointgrp <- function(x) {
   # Need to validate only once
-  if (methods::is(pointgrp, "pointgrp") && attr(pointgrp, "validated")) {
-    return(pointgrp)
+  if (methods::is(x, "pointgrp") && attr(x, "validated")) {
+    return(x)
   }
 
   # Validate class items and attributes
@@ -249,10 +249,10 @@
   )
   arg_names <- NULL
   .validate_basic(
-    pointgrp, "pointgrp", ".summarize_points", item_names,
+    x, "pointgrp", ".summarize_points", item_names,
     attr_names, arg_names
   )
 
-  attr(pointgrp, "validated") <- TRUE
-  pointgrp
+  attr(x, "validated") <- TRUE
+  x
 }
