@@ -140,33 +140,33 @@ create_prc <- function(pevals, scores = NULL, labels = NULL, x_bins = 1000,
 #
 # Validate 'roc_curve' object generated by create_roc()
 #
-.validate.roc_curve <- function(roc_curve) {
+.validate.roc_curve <- function(x) {
   # Need to validate only once
-  if (methods::is(roc_curve, "roc_curve") && attr(roc_curve, "validated")) {
-    return(roc_curve)
+  if (methods::is(x, "roc_curve") && attr(x, "validated")) {
+    return(x)
   }
 
   # Validate class items and attributes
-  .validate_curve(roc_curve, "roc_curve", "create_roc")
+  .validate_curve(x, "roc_curve", "create_roc")
 
-  attr(roc_curve, "validated") <- TRUE
-  roc_curve
+  attr(x, "validated") <- TRUE
+  x
 }
 
 #
 # Validate 'prc_curve' object generated by create_roc()
 #
-.validate.prc_curve <- function(prc_curve) {
+.validate.prc_curve <- function(x) {
   # Need to validate only once
-  if (methods::is(prc_curve, "prc_curve") && attr(prc_curve, "validated")) {
-    return(prc_curve)
+  if (methods::is(x, "prc_curve") && attr(x, "validated")) {
+    return(x)
   }
 
   # Validate class items and attributes
-  .validate_curve(prc_curve, "prc_curve", "create_prc")
+  .validate_curve(x, "prc_curve", "create_prc")
 
-  attr(prc_curve, "validated") <- TRUE
-  prc_curve
+  attr(x, "validated") <- TRUE
+  x
 }
 
 #
@@ -206,10 +206,10 @@ create_prc <- function(pevals, scores = NULL, labels = NULL, x_bins = 1000,
 #
 # Validate 'curves' object generated by create_curves()
 #
-.validate.curves <- function(curves) {
+.validate.curves <- function(x) {
   # Need to validate only once
-  if (methods::is(curves, "curves") && attr(curves, "validated")) {
-    return(curves)
+  if (methods::is(x, "curves") && attr(x, "validated")) {
+    return(x)
   }
 
   # Validate class items and attributes
@@ -223,14 +223,14 @@ create_prc <- function(pevals, scores = NULL, labels = NULL, x_bins = 1000,
     "modname", "dsid", "keep_fmdat", "keep_cmats"
   )
   .validate_basic(
-    curves, "curves", "calc_measures", item_names, attr_names,
+    x, "curves", "calc_measures", item_names, attr_names,
     arg_names
   )
 
   # Check values of class items
-  curves[["roc"]] <- .validate(curves[["roc"]])
-  curves[["prc"]] <- .validate(curves[["prc"]])
+  x[["roc"]] <- .validate(x[["roc"]])
+  x[["prc"]] <- .validate(x[["prc"]])
 
-  attr(curves, "validated") <- TRUE
-  curves
+  attr(x, "validated") <- TRUE
+  x
 }
