@@ -46,21 +46,22 @@ df1_create_mmcurves <- function(raw_curves = FALSE) {
   l4 <- c(1, 1, 0, 1)
   labels <- join_labels(l1, l2, l3, l4)
 
-  mdat <- mmdata(scores, labels, modnames = c("m1", "m2"), dsids = c(1, 2),
-                 expd_first = "modnames")
+  mdat <- mmdata(scores, labels,
+    modnames = c("m1", "m2"), dsids = c(1, 2),
+    expd_first = "modnames"
+  )
   evalmod(mdat, raw_curves = raw_curves)
 }
 
 df1_comp_dfs <- function(df1, df2) {
-  expect_equal(names(df1), names(df2))
+  testthat::expect_equal(names(df1), names(df2))
 
   for (vname in names(df1)) {
-    expect_equal(df1[[vname]], df2[[vname]])
+    testthat::expect_equal(df1[[vname]], df2[[vname]])
   }
 }
 
 test_that("as.data.frame sscurves", {
-
   data(P10N10)
   curves <- evalmod(scores = P10N10$scores, labels = P10N10$labels)
 
@@ -73,17 +74,17 @@ test_that("as.data.frame sscurves", {
 
 
 test_that("as.data.frame sscurves - dsid_modname", {
-
   data(P10N10)
   curves <- evalmod(scores = P10N10$scores, labels = P10N10$labels)
 
   curve_df <- as.data.frame(curves, raw_curves = TRUE, check_ggplot = TRUE)
-  expect_equal(as.character(curve_df$dsid_modname),
-               paste(curve_df$modname, curve_df$dsid, sep = ":"))
+  expect_equal(
+    as.character(curve_df$dsid_modname),
+    paste(curve_df$modname, curve_df$dsid, sep = ":")
+  )
 })
 
 test_that("as.data.frame mscurves", {
-
   curves <- df1_create_mscurves()
 
   curve_df <- as.data.frame(curves)
@@ -92,19 +93,21 @@ test_that("as.data.frame mscurves", {
   curve_df2 <- suppressWarnings(as.data.frame(curves, use_rcpp = FALSE))
   df1_comp_dfs(curve_df, curve_df2)
 
+  curve_df3 <- suppressWarnings(as.data.frame(curves, use_rcpp = TRUE))
+  df1_comp_dfs(curve_df, curve_df3)
 })
 
 test_that("as.data.frame mscurves - dsid_modname", {
-
   curves <- df1_create_mscurves()
 
   curve_df <- as.data.frame(curves, raw_curves = TRUE, check_ggplot = TRUE)
-  expect_equal(as.character(curve_df$dsid_modname),
-               paste(curve_df$modname, curve_df$dsid, sep = ":"))
+  expect_equal(
+    as.character(curve_df$dsid_modname),
+    paste(curve_df$modname, curve_df$dsid, sep = ":")
+  )
 })
 
 test_that("as.data.frame smcurves", {
-
   curves <- df1_create_smcurves(raw_curves = TRUE)
 
   curve_df <- as.data.frame(curves)
@@ -114,17 +117,30 @@ test_that("as.data.frame smcurves", {
   df1_comp_dfs(curve_df, curve_df2)
 })
 
+test_that("as.data.frame smcurves without rawcurves", {
+  curves <- df1_create_smcurves(raw_curves = FALSE)
+
+  curve_df <- as.data.frame(curves)
+  expect_true(is.data.frame(curve_df))
+
+  curve_df2 <- suppressWarnings(as.data.frame(curves,
+    raw_curves = FALSE,
+    use_rcpp = FALSE
+  ))
+  df1_comp_dfs(curve_df, curve_df2)
+})
+
 test_that("as.data.frame smcurves - dsid_modname", {
-
   curves <- df1_create_smcurves(raw_curves = TRUE)
 
   curve_df <- as.data.frame(curves, raw_curves = TRUE, check_ggplot = TRUE)
-  expect_equal(as.character(curve_df$dsid_modname),
-               paste(curve_df$modname, curve_df$dsid, sep = ":"))
+  expect_equal(
+    as.character(curve_df$dsid_modname),
+    paste(curve_df$modname, curve_df$dsid, sep = ":")
+  )
 })
 
 test_that("as.data.frame mmcurves", {
-
   curves <- df1_create_mmcurves(raw_curves = TRUE)
 
   curve_df <- as.data.frame(curves)
@@ -134,19 +150,42 @@ test_that("as.data.frame mmcurves", {
   df1_comp_dfs(curve_df, curve_df2)
 })
 
-test_that("as.data.frame mmcurves - dsid_modname", {
+test_that("as.data.frame mmcurves without rawcurves", {
+  curves <- df1_create_mmcurves(raw_curves = FALSE)
 
+  curve_df <- as.data.frame(curves)
+  expect_true(is.data.frame(curve_df))
+
+  curve_df2 <- suppressWarnings(as.data.frame(
+    raw_curves = FALSE,
+    curves, use_rcpp = FALSE
+  ))
+  df1_comp_dfs(curve_df, curve_df2)
+})
+
+test_that("as.data.frame mmcurves - dsid_modname", {
   curves <- df1_create_mmcurves(raw_curves = TRUE)
 
   curve_df <- as.data.frame(curves, raw_curves = TRUE, check_ggplot = TRUE)
-  expect_equal(as.character(curve_df$dsid_modname),
-               paste(curve_df$modname, curve_df$dsid, sep = ":"))
+  expect_equal(
+    as.character(curve_df$dsid_modname),
+    paste(curve_df$modname, curve_df$dsid, sep = ":")
+  )
+})
+
+test_that("as.data mode", {
+  data(P10N10)
+  curves <- evalmod(scores = P10N10$scores, labels = P10N10$labels)
+  attr(curves, "args")[["mode"]] <- "x"
+  expect_error(as.data.frame(curves), "Invalid mode")
 })
 
 test_that("as.data raw_curve option sscurves", {
   get_args <- function(x, ...) {
-    .get_dataframe_arglist(attr(x, "args"), def_raw_curves = TRUE,
-                                      ...)
+    .get_dataframe_arglist(attr(x, "args"),
+      def_raw_curves = TRUE,
+      ...
+    )
   }
 
   data(P10N10)
@@ -164,8 +203,10 @@ test_that("as.data raw_curve option sscurves", {
 
 test_that("as.data raw_curve option mscurves", {
   get_args <- function(x, ...) {
-    .get_dataframe_arglist(attr(x, "args"), def_raw_curves = TRUE,
-                                      ...)
+    .get_dataframe_arglist(attr(x, "args"),
+      def_raw_curves = TRUE,
+      ...
+    )
   }
 
   curves1 <- df1_create_mscurves()
@@ -182,8 +223,10 @@ test_that("as.data raw_curve option mscurves", {
 
 test_that("as.data raw_curve option smcurves", {
   get_args <- function(x, ...) {
-    .get_dataframe_arglist(attr(x, "args"), def_raw_curves = NULL,
-                                      ...)
+    .get_dataframe_arglist(attr(x, "args"),
+      def_raw_curves = NULL,
+      ...
+    )
   }
 
   curves1 <- df1_create_smcurves()
@@ -211,8 +254,10 @@ test_that("as.data raw_curve option smcurves", {
 
 test_that("as.data raw_curve option mmcurves", {
   get_args <- function(x, ...) {
-    .get_dataframe_arglist(attr(x, "args"), def_raw_curves = NULL,
-                                      ...)
+    .get_dataframe_arglist(attr(x, "args"),
+      def_raw_curves = NULL,
+      ...
+    )
   }
 
   curves1 <- df1_create_mmcurves()
